from . import api  # noqa
from . import check  # noqa
from . import error  # noqa
from . import ws  # noqa

from .ws.web_service import WebService  # noqa

wsapi = api.decorators

__version__ = '4.0.1'
